@@ -1,4 +1,3 @@
-# vim: set fileencoding=utf-8 :
 """
 ~~~~~~~
 Classes
@@ -9,8 +8,6 @@ Contains :class:`DictableModel` that can be used as a base class for
 
 """
 
-from __future__ import absolute_import, division
-
 from dictalchemy import utils
 
 
@@ -20,13 +17,6 @@ class DictableModel(object):
     Contains the methods :meth:`DictableModel.__iter__`,
     :meth:`DictableModel.asdict` and :meth:`DictableModel.fromdict`.
 
-    Example usage:
-
-        >>> from dictalchemy import DictableModel
-        >>> from slqlachemy.ext.declarative import declarative_base
-        >>> Base = declarative_base(cls=DictableModel)
-
-
     :ivar dictalchemy_exclude: List of properties that should always be \
             excluded.
     :ivar dictalchemy_exclude_underscore: If True properties starting with an \
