@@ -1,11 +1,9 @@
-# vim: set fileencoding=utf-8 :
 """
 ~~~~~~~~~
 Constants
 ~~~~~~~~~
 
 """
-from __future__ import absolute_import, division
 
 default_exclude = None
 """Default value for asdict_exclude"""
